/***********************************************************
 * $Id: AdditionalHeader.java 563 2012-01-09 09:28:27Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 09.01.2012
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http;

import java.io.Serializable;
import java.util.regex.Pattern;

import javax.servlet.http.HttpServletRequest;

/**
 * A configuration POJO, which lets the user configure additional
 * headers to be delivered based on MIME type and/ or path regex matching.
 */
public class AdditionalHeader implements Serializable {

	private static final long serialVersionUID = 1702841976833425700L;
	private Pattern pathRegex;
	private Pattern mimeTypeRegex;
	private String header;
	private String value;
		
	public AdditionalHeader() {
		super();
	}
	
	/**
	 * @param header The name of the header to be delivered.
	 * @param value The value of the header to be delivered.
	 * @param pathRegex A regular expression to match the extra path info as returned
	 *                  by {@link HttpServletRequest#getPathInfo()} after any alias
	 *                  matching as per {@link ResourceServlet#setAliases(java.util.Map)}.
	 *                  If <code>null</code>, any path matches.
	 * @param mimeTypeRegex A regular expression to match the MIME type of a delivered resource.
	 *                  If <code>null</code>, any MIME type matches.
	 */
	public AdditionalHeader(String header, String value, Pattern pathRegex,
			Pattern mimeTypeRegex) {
		super();
		this.header = header;
		this.value = value;
		this.pathRegex = pathRegex;
		this.mimeTypeRegex = mimeTypeRegex;
	}

	/**
	 * @return A regular expression to match extra path infos.
	 */
	public Pattern getPathRegex() {
		return this.pathRegex;
	}

	/**
	 * @param pathRegex A regular expression to match the extra path info as returned
	 *                  by {@link HttpServletRequest#getPathInfo()} after any alias
	 *                  matching as per {@link ResourceServlet#setAliases(java.util.Map)}.
	 *                  If <code>null</code>, any path matches.
	 */
	public void setPathRegex(Pattern pathRegex) {
		this.pathRegex = pathRegex;
	}

	/**
	 * @return a regular expression to the MIME type of a delivered resource.
	 */
	public Pattern getMimeTypeRegex() {
		return this.mimeTypeRegex;
	}
	
	/**
	 * @param mimeTypeRegex A regular expression to match the MIME type of a delivered resource.
	 *                  If <code>null</code>, any MIME type matches.
	 */
	public void setMimeTypeRegex(Pattern mimeTypeRegex) {
		this.mimeTypeRegex = mimeTypeRegex;
	}

	/**
	 * @return The name of the header to be delivered.
	 */
	public String getHeader() {
		return this.header;
	}
	
	/**
	 * @param header The name of the header to be delivered.
	 */
	public void setHeader(String header) {
		this.header = header;
	}
	
	/**
	 * @return The value of the header to be delivered.
	 */
	public String getValue() {
		return this.value;
	}
	
	/**
	 * @param value The value of the header to be delivered.
	 */
	public void setValue(String value) {
		this.value = value;
	}
	
}
