/***********************************************************
 * $Id: LoginRequiredException.java 796 2013-02-19 16:28:09Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 18.05.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.sec;

/**
 * An exception thrown, whenever a user is not logged in and a login URL
 * should be propagated to the web application.
 * 
 * @see HttpCheckLoginHelper#sendLoginRequired(javax.servlet.http.HttpServletResponse, String)
 */
public class LoginRequiredException extends RuntimeException {
	
	private static final long serialVersionUID = 8809106474178517570L;
	private String loginUrl;

	/**
	 * Default constructor for the sake of GWT deserialization code.
	 */
	public LoginRequiredException() {
		super();
	}
	
	/**
	 * @param loginUrl The URL of the login servlet.
	 */
	public LoginRequiredException(String loginUrl) {
		super();
		this.loginUrl = loginUrl;
	}

	/**
	 * @param message The message of the underlying exception.
	 * @param loginUrl The URL of the login servlet.
	 */
	public LoginRequiredException(String message, String loginUrl) {
		super(message);
		this.loginUrl = loginUrl;
	}
	
	/**
	 * @return The login URL as returned by {@link HttpLoginService#getLoginUrl()}.
	 */
	public String getLoginUrl() {
		return this.loginUrl;
	}
}
